@@ -3,7 +3,7 @@ package Stuff;
 use Stuff::Features;
 use Stuff::Base;
 
-our $VERSION = '0.0.8';
+our $VERSION = '0.0.9';
 
 sub import {
   shift;
@@ -24,7 +24,7 @@ Writing of documentation still in progress.
 
 =head1 SYNOPSIS
 
-Frontend to C<Stuff::Features>, C<Stuff::Base> and C<Stuff::Defs>.
+Frontend to C<Stuff::Features>, C<Stuff::Base> and C<Stuff::Subs>.
 
   use Stuff @args;
 
@@ -33,11 +33,11 @@ is equivalent to
   use Stuff::Features;
   use Stuff::Base @args;
 
-It is better to use C<use Stuff> in your code, instead of separate C<Stuff::Features>, C<Stuff::Base> and C<Stuff::Defs>.
+It is better to use C<use Stuff> in your code, instead of separate C<Stuff::Features>, C<Stuff::Base> and C<Stuff::Subs>.
 
 =head1 SEE ALSO
 
-L<Stuff::Features>, L<Stuff::Base>, L<Stuff::Defs>, L<Stuff::Exception>
+L<Stuff::Features>, L<Stuff::Base>, L<Stuff::Subs>, L<Stuff::Exception>
 
 =head1 REPOSITORY
 
