@@ -3,6 +3,7 @@ package Stuff::Features;
 use 5.008;
 use strict;
 use utf8;
+use mro;
 no warnings;
 
 use constant HAS_FEATURE => eval { require feature; };
@@ -11,7 +12,9 @@ use constant HAS_FEATURE => eval { require feature; };
 binmode( $_, ':utf8' )
   for qw/STDIN STDOUT STDERR/;
 
-sub import {
+sub init {
+  my $package = shift || caller;
+  
   # use strict;
   strict->import;
   
@@ -26,6 +29,9 @@ sub import {
     taint threads unpack
   / );
   
+  # use mro 'c3';
+  mro::set_mro( $package, 'c3' );
+  
   # use utf8;
   utf8->import;
   
@@ -36,6 +42,10 @@ sub import {
   feature->import( qw/say switch/ ) if HAS_FEATURE;
 }
 
+sub import {
+  init( scalar caller );
+}
+
 1;
 
 =head1 NAME
@@ -58,6 +68,7 @@ is a short replacement for
     taint threads unpack
   / );
   use utf8;
+  use mro 'c3';
   use open qw/:utf8 :std/;
   use feature qw/say switch/;
 
